# -*- coding: utf-8 -*-
# Generated by Django 1.9.1 on 2016-12-13 12:38
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('hidash', '0005_auto_20161213_1214'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='scheduledreport',
            name='report',
        ),
        migrations.AddField(
            model_name='scheduledreport',
            name='group',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='hidash.Group'),
        ),
        migrations.AddField(
            model_name='scheduledreport',
            name='template',
            field=models.FileField(blank=True, upload_to=b'template_docs'),
        ),
    ]
