# -*- coding: utf-8 -*-
# Generated by Django 1.9.1 on 2016-12-13 12:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hidash', '0004_auto_20161012_0739'),
    ]

    operations = [
        migrations.AddField(
            model_name='scheduledreportparam',
            name='is_parameter_value_sql_function',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='chartparameter',
            name='parameter_type',
            field=models.IntegerField(blank=True, choices=[(0, b'dropdown'), (1, b'dateTime'), (2, b'dateRange'), (3, b'periodicDatePicker')], null=True),
        ),
    ]
